@@ -1068,7 +1068,6 @@ def LFP(data):
 def PlotInteraction(interactions, **kwargs):
   """
   Plots a bar with interactions times of the determined body with the fields.
-
   Parameters
   ----------
   interactions : pandas DataFrame
@@ -1100,16 +1099,13 @@ def PlotInteraction(interactions, **kwargs):
       Determine the resolutions (dpi), default = 80.
   ax : fig, optional
       Creates an 'axs' to be added to a figure created outside the role by the user.
-
   Returns
   -------
   out : plot
       The output of the function is the figure with the interactions times with fields.
-
   See Also
   --------
   For more information and usage examples: https://github.com/pyratlib/pyrat
-
   Notes
   -----
   This function was developed based on DLC outputs and is able to support 
@@ -1125,6 +1121,9 @@ def PlotInteraction(interactions, **kwargs):
   figureTitle = kwargs.get('figureTitle')
   fps = kwargs.get('fps')
   ax = kwargs.get('ax')
+  aspect = kwargs.get('aspect')
+  if type(aspect) == type(None):
+    aspect = 'equal'
   if type(fps) == type(None):
     fps = 30
   hSize = kwargs.get('hSize')
@@ -1166,19 +1165,22 @@ def PlotInteraction(interactions, **kwargs):
     for i in range (1,int(interactions.obj.max())+1):
       plt.barh(0,times[i], left=starts[i], height = barHeight, label = "Field "+str(i))
 
+    plt.title(figureTitle,fontsize=fontsize)
     plt.legend(ncol=int(interactions.obj.max()))
     plt.xlim(init, finish)
     plt.yticks([])
     plt.xticks(fontsize = fontsize*0.8)
     plt.xlabel("Time (s)",fontsize=fontsize)
-    plt.ylim([barHeight,barHeight])
+    plt.ylim([-barHeight,barHeight])
     plt.show()
     if type(saveName) != type(None):
         plt.savefig(saveName+figformat)
   else:
     for i in range (1,int(interactions.obj.max())+1):
       ax.barh(0,times[i], left=starts[i], height = barHeight, label = "Field "+str(i))
-    ax.set_aspect('equal')
+    ax.set_title(figureTitle, fontsize=fontsize)
+    if aspect == type(None):
+      ax.set_aspect(aspect)
     ax.set_xlim([init, finish])
     ax.set_yticklabels([])
     ax.get_yaxis().set_visible(False)
@@ -1186,4 +1188,5 @@ def PlotInteraction(interactions, **kwargs):
     ax.tick_params(axis='y', labelsize=fontsize*.8)
     ax.legend(ncol=int(interactions.obj.max()),fontsize=fontsize*.8)
     ax.set_xlabel('Time (s)',fontsize=fontsize)
+
     ax.set_ylim([-barHeight,barHeight])
